pm4py.algo.organizational\_mining.resource\_profiles.variants package
=====================================================================

Submodules
----------

pm4py.algo.organizational\_mining.resource\_profiles.variants.log module
------------------------------------------------------------------------

.. automodule:: pm4py.algo.organizational_mining.resource_profiles.variants.log
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.organizational\_mining.resource\_profiles.variants.pandas module
---------------------------------------------------------------------------

.. automodule:: pm4py.algo.organizational_mining.resource_profiles.variants.pandas
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.organizational_mining.resource_profiles.variants
   :members:
   :undoc-members:
   :show-inheritance:
